searchData={"content_type":"text/markdown","items":[{"doc":"Nested provides utilities for accessing, extracting, and manipulating nested data structures\nin Elixir maps and lists with ease and safety.\n\nThis module is particularly useful when working with:\n- JSON-like data structures\n- Configuration maps\n- API responses with nested data\n- Complex data transformations","ref":"Nested.html","title":"Nested","type":"module"},{"doc":"- **Safe navigation**: Gracefully handles missing paths without raising exceptions\n- **Flexible path syntax**: Supports integers, atoms, maps for filtering, and functions\n- **Map filtering**: Find list items by matching specific criteria\n- **Deep traversal**: Transform entire data structures with custom logic\n- **Struct handling**: Automatically converts structs while preserving special types","ref":"Nested.html#module-key-features","title":"Key Features - Nested","type":"module"},{"doc":"Paths are lists that can contain:\n- `integer` - List index or map key\n- `atom` - Map key or keyword list key\n- `string` - Map string key\n- `map` - Filter criteria for finding items in lists\n- `function/1` - Custom predicate for finding items in lists\n- `\"*\"` - Wildcard to match all items (extract only)","ref":"Nested.html#module-path-syntax","title":"Path Syntax - Nested","type":"module"},{"doc":"Basic usage with nested maps and lists:\n\n    data = %{\n      users: [\n        %{name: \"Alice\", age: 30, active: true},\n        %{name: \"Bob\", age: 25, active: false}\n      ],\n      config: %{database: %{host: \"localhost\", port: 5432}}\n    }\n\n    # Simple path navigation\n    Nested.get(data, [:users, 0, :name])\n    #=> \"Alice\"\n\n    # Map filtering - find user by criteria\n    Nested.get(data, [:users, %{active: true}, :name])\n    #=> \"Alice\"\n\n    # Function filtering - find user with custom logic\n    Nested.get(data, [:users, &(&1.age > 26), :name])\n    #=> \"Alice\"\n\n    # Extract all matching values\n    Nested.extract(data, [:users, \"*\", :name])\n    #=> [\"Alice\", \"Bob\"]","ref":"Nested.html#module-examples","title":"Examples - Nested","type":"module"},{"doc":"For convenience, you can also use query strings with `Nested.key/2`:\n\n    # Basic dot notation\n    Nested.get(data, Nested.key(\"users.0.name\"))\n    #=> \"Alice\"\n\n    # Bracket filtering\n    Nested.get(data, Nested.key(\"users[active=true].name\"))\n    #=> \"Alice\"\n\n    # Extract with wildcards\n    Nested.extract(data, Nested.key(\"users[*].name\"))\n    #=> [\"Alice\", \"Bob\"]\n\n    # String keys for JSON data\n    Nested.get(json_data, Nested.key(\"users.0.name\", :string))","ref":"Nested.html#module-query-string-syntax","title":"Query String Syntax - Nested","type":"module"},{"doc":"Replace values with `\"***\"` for keys that contain any of the specified keywords.\n\nThis function is useful for sanitizing sensitive data in logs, API responses,\nor when displaying data to users who shouldn't see certain fields.","ref":"Nested.html#censor/2","title":"Nested.censor/2","type":"function"},{"doc":"- `object` - The data structure to censor\n- `keywords` - List of strings to match against key names (case-sensitive, partial matching)","ref":"Nested.html#censor/2-parameters","title":"Parameters - Nested.censor/2","type":"function"},{"doc":"user_data = %{\n      username: \"alice\",\n      email: \"alice@example.com\",\n      password: \"secret123\",\n      api_token: \"abc123xyz\",\n      user_preferences: %{theme: \"dark\"}\n    }\n\n    # Censor password-related fields\n    Nested.censor(user_data, [\"pass\", \"token\", \"secret\"])\n    #=> %{\n      username: \"alice\",\n      email: \"alice@example.com\",\n      password: \"***\",\n      api_token: \"***\",\n      user_preferences: %{theme: \"dark\"}\n    }\n\n    # Censor nested sensitive data\n    api_response = %{\n      users: [\n        %{name: \"Alice\", social_security: \"123-45-6789\", email: \"alice@example.com\"},\n        %{name: \"Bob\", social_security: \"987-65-4321\", email: \"bob@example.com\"}\n      ],\n      admin_password: \"supersecret\"\n    }\n\n    Nested.censor(api_response, [\"social\", \"password\"])\n    #=> %{\n      users: [\n        %{name: \"Alice\", social_security: \"***\", email: \"alice@example.com\"},\n        %{name: \"Bob\", social_security: \"***\", email: \"bob@example.com\"}\n      ],\n      admin_password: \"***\"\n    }","ref":"Nested.html#censor/2-examples","title":"Examples - Nested.censor/2","type":"function"},{"doc":"- Matching is **case-sensitive**\n- Uses **partial matching** (substring search)\n- Checks against the string representation of keys\n- Works with atom keys, string keys, and any key type that can be converted to string","ref":"Nested.html#censor/2-matching-behavior","title":"Matching Behavior - Nested.censor/2","type":"function"},{"doc":"- Sanitizing logs before writing to files\n- Preparing data for display in admin interfaces\n- Removing sensitive data from error reports\n- Creating safe data dumps for debugging","ref":"Nested.html#censor/2-use-cases","title":"Use Cases - Nested.censor/2","type":"function"},{"doc":"Remove all `nil` values from nested maps and lists.\n\nThis function is useful for cleaning up data structures that may contain\nunwanted `nil` values, often resulting from API responses or incomplete data.","ref":"Nested.html#clean_nil/1","title":"Nested.clean_nil/1","type":"function"},{"doc":"# Clean map with nil values\n    data = %{\n      name: \"Alice\",\n      email: nil,\n      profile: %{\n        age: 30,\n        bio: nil,\n        settings: %{theme: \"dark\", notifications: nil}\n      }\n    }\n\n    Nested.clean_nil(data)\n    #=> %{\n      name: \"Alice\",\n      profile: %{\n        age: 30,\n        settings: %{theme: \"dark\"}\n      }\n    }\n\n    # Clean list with nil values\n    users = [\n      %{name: \"Alice\", email: \"alice@example.com\"},\n      nil,\n      %{name: \"Bob\", email: nil}\n    ]\n\n    Nested.clean_nil(users)\n    #=> [\n      %{name: \"Alice\", email: \"alice@example.com\"},\n      %{name: \"Bob\"}\n    ]","ref":"Nested.html#clean_nil/1-examples","title":"Examples - Nested.clean_nil/1","type":"function"},{"doc":"- Cleaning API response data before storage\n- Preparing data for JSON serialization\n- Removing optional fields that weren't provided\n- Database record cleanup","ref":"Nested.html#clean_nil/1-use-cases","title":"Use Cases - Nested.clean_nil/1","type":"function"},{"doc":"Extract multiple values from nested data structures using pattern matching and wildcards.\n\nThis function is powerful for collecting data from multiple locations in complex structures.\nUnlike `get/3` and `fetch/2` which return single values, `extract/2` always returns a list\nof all matching values.","ref":"Nested.html#extract/2","title":"Nested.extract/2","type":"function"},{"doc":"- `object` - The data structure to query (map or list)\n- `paths` - List of keys/indices/filters, may include wildcards (`\"*\"`)","ref":"Nested.html#extract/2-parameters","title":"Parameters - Nested.extract/2","type":"function"},{"doc":"Always returns a list, empty if no matches found.","ref":"Nested.html#extract/2-returns","title":"Returns - Nested.extract/2","type":"function"},{"doc":"Use `\"*\"` to match all items in a list:\n\n    data = %{\n      teams: [\n        %{name: \"Backend\", members: [\"Alice\", \"Bob\"]},\n        %{name: \"Frontend\", members: [\"Charlie\", \"Diana\"]}\n      ]\n    }\n\n    # Get all team names\n    Nested.extract(data, [:teams, \"*\", :name])\n    #=> [\"Backend\", \"Frontend\"]\n\n    # Get all member lists\n    Nested.extract(data, [:teams, \"*\", :members])\n    #=> [[\"Alice\", \"Bob\"], [\"Charlie\", \"Diana\"]]","ref":"Nested.html#extract/2-wildcard-usage","title":"Wildcard Usage - Nested.extract/2","type":"function"},{"doc":"users = [\n      %{name: \"Alice\", department: \"Engineering\", active: true},\n      %{name: \"Bob\", department: \"Sales\", active: false},\n      %{name: \"Charlie\", department: \"Engineering\", active: true}\n    ]\n\n    data = %{users: users}\n\n    # Extract all user names\n    Nested.extract(data, [:users, \"*\", :name])\n    #=> [\"Alice\", \"Bob\", \"Charlie\"]\n\n    # Extract names of active users only\n    Nested.extract(data, [:users, %{active: true}, :name])\n    #=> [\"Alice\", \"Charlie\"]\n\n    # Extract names of engineering department\n    Nested.extract(data, [:users, %{department: \"Engineering\"}, :name])\n    #=> [\"Alice\", \"Charlie\"]\n\n    # Extract with function filtering\n    senior_users = fn user -> user.experience_years > 5 end\n    Nested.extract(data, [:users, senior_users, :name])","ref":"Nested.html#extract/2-filtering-examples","title":"Filtering Examples - Nested.extract/2","type":"function"},{"doc":"company = %{\n      departments: [\n        %{\n          name: \"Engineering\",\n          teams: [\n            %{name: \"Backend\", skills: [\"elixir\", \"postgres\"]},\n            %{name: \"Frontend\", skills: [\"react\", \"typescript\"]}\n          ]\n        },\n        %{\n          name: \"Design\",\n          teams: [\n            %{name: \"UX\", skills: [\"figma\", \"research\"]},\n            %{name: \"Visual\", skills: [\"photoshop\", \"illustration\"]}\n          ]\n        }\n      ]\n    }\n\n    # Get all team names across all departments\n    Nested.extract(company, [:departments, \"*\", :teams, \"*\", :name])\n    #=> [\"Backend\", \"Frontend\", \"UX\", \"Visual\"]\n\n    # Get all skills across all teams\n    Nested.extract(company, [:departments, \"*\", :teams, \"*\", :skills])\n    #=> [[\"elixir\", \"postgres\"], [\"react\", \"typescript\"], [\"figma\", \"research\"], [\"photoshop\", \"illustration\"]]","ref":"Nested.html#extract/2-complex-nested-extraction","title":"Complex Nested Extraction - Nested.extract/2","type":"function"},{"doc":"Query data nested in maps and lists, returning `{:ok, value}` or `:error`.\n\nThis function provides explicit error handling for cases where you need to distinguish\nbetween a successful lookup that returns `nil` and a failed lookup.","ref":"Nested.html#fetch/2","title":"Nested.fetch/2","type":"function"},{"doc":"- `object` - The data structure to query (map or list)\n- `paths` - List of keys/indices/filters defining the path to the desired value","ref":"Nested.html#fetch/2-parameters","title":"Parameters - Nested.fetch/2","type":"function"},{"doc":"- `{:ok, value}` - If the path exists and leads to a value\n- `:error` - If the path doesn't exist or any step fails","ref":"Nested.html#fetch/2-returns","title":"Returns - Nested.fetch/2","type":"function"},{"doc":"data = %{\n      users: [\n        %{name: \"Alice\", email: nil},\n        %{name: \"Bob\", email: \"bob@example.com\"}\n      ]\n    }\n\n    # Successful lookup\n    Nested.fetch(data, [:users, 0, :name])\n    #=> {:ok, \"Alice\"}\n\n    # Successful lookup returning nil\n    Nested.fetch(data, [:users, 0, :email])\n    #=> {:ok, nil}\n\n    # Failed lookup\n    Nested.fetch(data, [:users, 5, :name])\n    #=> :error\n\n    # Map filtering\n    Nested.fetch(data, [:users, %{email: \"bob@example.com\"}, :name])\n    #=> {:ok, \"Bob\"}\n\n    # No match found\n    Nested.fetch(data, [:users, %{email: \"nonexistent@example.com\"}, :name])\n    #=> :error","ref":"Nested.html#fetch/2-examples","title":"Examples - Nested.fetch/2","type":"function"},{"doc":"","ref":"Nested.html#fetch/2-advanced-filtering","title":"Advanced Filtering - Nested.fetch/2","type":"function"},{"doc":"Find items in lists by matching map criteria:\n\n    users = [\n      %{name: \"Alice\", role: \"admin\", active: true},\n      %{name: \"Bob\", role: \"user\", active: false}\n    ]\n\n    # Find admin user\n    Nested.fetch(%{users: users}, [:users, %{role: \"admin\"}, :name])\n    #=> {:ok, \"Alice\"}\n\n    # Find by multiple criteria\n    Nested.fetch(%{users: users}, [:users, %{role: \"admin\", active: true}, :name])\n    #=> {:ok, \"Alice\"}","ref":"Nested.html#fetch/2-map-filtering","title":"Map Filtering - Nested.fetch/2","type":"function"},{"doc":"Use custom predicates for complex matching:\n\n    # Find user with specific condition\n    older_than_25 = fn user -> user.age > 25 end\n    Nested.fetch(data, [:users, older_than_25, :name])","ref":"Nested.html#fetch/2-function-filtering","title":"Function Filtering - Nested.fetch/2","type":"function"},{"doc":"Safely query data nested in maps and lists, returning a default value if the path doesn't exist.\n\nThis is the safest way to access nested data as it never raises exceptions.","ref":"Nested.html#get/3","title":"Nested.get/3","type":"function"},{"doc":"- `object` - The data structure to query (map or list)\n- `paths` - List of keys/indices/filters defining the path to the desired value\n- `default` - Value to return if path doesn't exist (defaults to `nil`)","ref":"Nested.html#get/3-parameters","title":"Parameters - Nested.get/3","type":"function"},{"doc":"data = %{\n      users: [\n        %{name: \"Alice\", skills: [\"elixir\", \"js\"]},\n        %{name: \"Bob\", skills: [\"python\"]}\n      ]\n    }\n\n    # Basic access\n    Nested.get(data, [:users, 0, :name])\n    #=> \"Alice\"\n\n    # With custom default\n    Nested.get(data, [:users, 5, :name], \"Unknown\")\n    #=> \"Unknown\"\n\n    # Map filtering\n    Nested.get(data, [:users, %{name: \"Bob\"}, :skills])\n    #=> [\"python\"]\n\n    # Function filtering\n    has_elixir = fn user -> \"elixir\" in user.skills end\n    Nested.get(data, [:users, has_elixir, :name])\n    #=> \"Alice\"\n\n    # Keyword lists\n    config = [database: [host: \"localhost\", port: 5432]]\n    Nested.get(config, [:database, :host])\n    #=> \"localhost\"","ref":"Nested.html#get/3-examples","title":"Examples - Nested.get/3","type":"function"},{"doc":"Parse a query string into a path list for use with other Nested functions.\n\nThis function converts a human-readable query string into the path format\nused by `get/3`, `fetch/2`, `extract/2`, and other functions.","ref":"Nested.html#key/2","title":"Nested.key/2","type":"function"},{"doc":"- `query_string` - String representation of the path\n- `key_type` - Default type for dot notation keys (`:atom` or `:string`, defaults to `:atom`)","ref":"Nested.html#key/2-parameters","title":"Parameters - Nested.key/2","type":"function"},{"doc":"# Basic usage\n    Nested.key(\"users.0.name\")\n    #=> [:users, 0, :name]\n\n    # String keys mode\n    Nested.key(\"config.database.host\", :string)  \n    #=> [\"config\", \"database\", \"host\"]\n\n    # Use with other functions\n    path = Nested.key(\"users[active=true].0.name\")\n    Nested.get(data, path)\n\nFor full syntax documentation, see `Nested.QueryParser.parse/2`.","ref":"Nested.html#key/2-examples","title":"Examples - Nested.key/2","type":"function"},{"doc":"Deeply merge two maps, recursively combining nested maps.\n\nWhen the same key exists in both maps:\n- If both values are maps, they are merged recursively\n- Otherwise, the value from the right map takes precedence","ref":"Nested.html#merge/2","title":"Nested.merge/2","type":"function"},{"doc":"- `left` - The base map\n- `right` - The map to merge into the base map (takes precedence)","ref":"Nested.html#merge/2-parameters","title":"Parameters - Nested.merge/2","type":"function"},{"doc":"# Simple merge\n    config_defaults = %{\n      database: %{host: \"localhost\", port: 5432, pool_size: 10},\n      cache: %{enabled: false, ttl: 3600}\n    }\n\n    user_config = %{\n      database: %{host: \"prod-db.example.com\", pool_size: 20},\n      cache: %{enabled: true},\n      logging: %{level: :info}\n    }\n\n    Nested.merge(config_defaults, user_config)\n    #=> %{\n      database: %{host: \"prod-db.example.com\", port: 5432, pool_size: 20},\n      cache: %{enabled: true, ttl: 3600},\n      logging: %{level: :info}\n    }","ref":"Nested.html#merge/2-examples","title":"Examples - Nested.merge/2","type":"function"},{"doc":"base = %{\n      settings: %{theme: \"light\", lang: \"en\"},\n      data: [1, 2, 3]\n    }\n\n    override = %{\n      settings: %{theme: \"dark\"},  # Map: merged recursively\n      data: [4, 5, 6]              # Non-map: completely replaced\n    }\n\n    Nested.merge(base, override)\n    #=> %{\n      settings: %{theme: \"dark\", lang: \"en\"},  # Recursive merge preserves 'lang'\n      data: [4, 5, 6]                          # Complete replacement\n    }","ref":"Nested.html#merge/2-conflict-resolution","title":"Conflict Resolution - Nested.merge/2","type":"function"},{"doc":"- Configuration management with defaults and overrides\n- Combining user preferences with system defaults\n- Merging API response data\n- Building composite data structures from multiple sources","ref":"Nested.html#merge/2-use-cases","title":"Use Cases - Nested.merge/2","type":"function"},{"doc":"- Creates new data structures; doesn't modify originals\n- Recursion depth matches the nesting depth of your data\n- Efficient for typical configuration and data merging scenarios","ref":"Nested.html#merge/2-performance-notes","title":"Performance Notes - Nested.merge/2","type":"function"},{"doc":"Convert structs to maps by removing internal Elixir metadata.\n\nThis function recursively converts all structs in a data structure to plain maps\nwhile preserving special types like DateTime. It's useful for serialization,\nlogging, or when you need plain data structures.","ref":"Nested.html#to_map/1","title":"Nested.to_map/1","type":"function"},{"doc":"defmodule User do\n      defstruct [:name, :email, :created_at]\n    end\n\n    defmodule Company do\n      defstruct [:name, :users]\n    end\n\n    user1 = %User{name: \"Alice\", email: \"alice@example.com\", created_at: ~U[2023-01-01 00:00:00Z]}\n    user2 = %User{name: \"Bob\", email: \"bob@example.com\", created_at: ~U[2023-01-02 00:00:00Z]}\n\n    company = %Company{\n      name: \"Tech Corp\",\n      users: [user1, user2]\n    }\n\n    Nested.to_map(company)\n    #=> %{\n      name: \"Tech Corp\",\n      users: [\n        %{name: \"Alice\", email: \"alice@example.com\", created_at: ~U[2023-01-01 00:00:00Z]},\n        %{name: \"Bob\", email: \"bob@example.com\", created_at: ~U[2023-01-02 00:00:00Z]}\n      ]\n    }","ref":"Nested.html#to_map/1-examples","title":"Examples - Nested.to_map/1","type":"function"},{"doc":"These special types are NOT converted to maps:\n- `DateTime`\n- `NaiveDateTime`\n- `Date`\n- `Time`","ref":"Nested.html#to_map/1-preserved-types","title":"Preserved Types - Nested.to_map/1","type":"function"},{"doc":"- Preparing struct data for JSON serialization\n- Logging structured data without internal metadata\n- Converting Ecto schemas to plain maps\n- API response formatting","ref":"Nested.html#to_map/1-use-cases","title":"Use Cases - Nested.to_map/1","type":"function"},{"doc":"Traverse nested data structures and apply transformations to each element.\n\nThis is the most powerful function in the module, allowing you to walk through\nand transform entire data structures with fine-grained control over the process.","ref":"Nested.html#traverse/2","title":"Nested.traverse/2","type":"function"},{"doc":"- `object` - The data structure to traverse (map, list, or struct)\n- `fun` - Function that receives each item and returns a transformation directive","ref":"Nested.html#traverse/2-parameters","title":"Parameters - Nested.traverse/2","type":"function"},{"doc":"The transformation function can return:\n\n- `:discard` - Remove the item completely\n- `{:skip, item}` - Keep the item but don't traverse its children\n- `{:next, item}` - Transform the item and continue traversing its children\n- `item` - Equivalent to `{:next, item}`","ref":"Nested.html#traverse/2-transformation-directives","title":"Transformation Directives - Nested.traverse/2","type":"function"},{"doc":"","ref":"Nested.html#traverse/2-examples","title":"Examples - Nested.traverse/2","type":"function"},{"doc":"data = %{\n      name: \"Product\",\n      price: 100,\n      tags: [\"electronics\", \"gadget\"]\n    }\n\n    # Double all numeric values\n    Nested.traverse(data, fn\n      {key, value} when is_number(value) -> {key, value * 2}\n      item -> item\n    end)\n    #=> %{name: \"Product\", price: 200, tags: [\"electronics\", \"gadget\"]}","ref":"Nested.html#traverse/2-basic-transformation","title":"Basic Transformation - Nested.traverse/2","type":"function"},{"doc":"user_data = %{\n      name: \"Alice\",\n      email: \"alice@example.com\",\n      password: \"secret123\",\n      internal_id: \"xyz789\"\n    }\n\n    # Remove sensitive data\n    Nested.traverse(user_data, fn\n      {:password, _} -> :discard\n      {:internal_id, _} -> :discard\n      item -> item\n    end)\n    #=> %{name: \"Alice\", email: \"alice@example.com\"}","ref":"Nested.html#traverse/2-removing-data","title":"Removing Data - Nested.traverse/2","type":"function"},{"doc":"api_response = %{\n      users: [\n        %{name: \"Alice\", temp_token: \"abc\", profile: %{age: 30, _debug: \"info\"}},\n        %{name: \"Bob\", temp_token: \"def\", profile: %{age: 25, _debug: \"info\"}}\n      ],\n      _metadata: %{request_id: \"123\", debug: true}\n    }\n\n    # Remove temporary and debug data\n    Nested.traverse(api_response, fn\n      {:temp_token, _} -> :discard\n      {key, _} when is_atom(key) and String.starts_with?(Atom.to_string(key), \"_\") -> :discard\n      item -> item\n    end)","ref":"Nested.html#traverse/2-complex-data-cleaning","title":"Complex Data Cleaning - Nested.traverse/2","type":"function"},{"doc":"# Skip processing certain branches\n    Nested.traverse(data, fn\n      {:sensitive_data, value} -> {:skip, {:sensitive_data, value}}  # Don't traverse children\n      {:public_data, value} -> {:next, {:public_data, process(value)}}  # Transform and traverse\n      item -> item\n    end)","ref":"Nested.html#traverse/2-conditional-processing","title":"Conditional Processing - Nested.traverse/2","type":"function"},{"doc":"The function automatically converts structs to maps (except for special types like DateTime):\n\n    defmodule User do\n      defstruct [:name, :email]\n    end\n\n    user = %User{name: \"Alice\", email: \"alice@example.com\"}\n\n    Nested.traverse(%{user: user}, fn item -> item end)\n    #=> %{user: %{name: \"Alice\", email: \"alice@example.com\"}}\n\nSpecial types that are preserved:\n- `DateTime`\n- `NaiveDateTime`\n- `Date`\n- `Time`","ref":"Nested.html#traverse/2-struct-handling","title":"Struct Handling - Nested.traverse/2","type":"function"},{"doc":"- The function creates new data structures; it doesn't modify in place\n- For large datasets, consider processing in chunks or using streams\n- Struct conversion has minimal overhead but creates new maps","ref":"Nested.html#traverse/2-performance-notes","title":"Performance Notes - Nested.traverse/2","type":"function"},{"doc":"Simple parser for converting query strings into path lists.","ref":"Nested.QueryParser.html","title":"Nested.QueryParser","type":"module"},{"doc":"Parse a query string into a path list.","ref":"Nested.QueryParser.html#parse/2","title":"Nested.QueryParser.parse/2","type":"function"},{"doc":"parse(\"users.0.name\")              #=> [:users, 0, :name]\n    parse(\"users[name=Alice].age\")     #=> [:users, %{name: \"Alice\"}, :age]\n    parse(\"users[*].name\")             #=> [:users, \"*\", :name]","ref":"Nested.QueryParser.html#parse/2-examples","title":"Examples - Nested.QueryParser.parse/2","type":"function"},{"doc":"# Nested\n\n**TODO: Add description**","ref":"readme.html","title":"Nested","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `nested` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nested, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - Nested","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}